#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef GETTEXT_PACKAGE
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_LIBSM
#undef PACKAGE_LOCALE_DIR
#undef PACKAGE_DATA_DIR
#undef PACKAGE_SOURCE_DIR
#undef NAUTILUS_PREFIX
#undef CVS_SOURCE 
#undef CORBA_INTERFACE
#undef MOZILLA_VERSION
#undef MOZILLA_SNAPSHOT
#undef ENABLE_APPLET
#undef HAVE__NL_PAPER_WIDTH_HEIGHT
#undef ENABLE_GNOME_FILE_SELECTOR
#undef ENABLE_EXPERIMENTAL_FILTERS
#undef HAVE_XINERAMA
#undef XPCOM_SHARED_LIB
#undef ENABLE_NAUTILUS_VIEW
#undef STRING_HEADER
#undef ENABLE_MOZILLA_EMBED
#undef ENABLE_GTKHTML_EMBED
#undef ENABLE_JUST_GNOMEVFS
#undef ENABLE_SIMPLE_MENUBAR
#undef MAINTAINER_MODE
